@@ -1,4 +1,4 @@
-use crate::deserialize::parse::{self, MaybeReplaceExt};
+use crate::deserialize::parse::{self};
 use std::cmp::{Ord, PartialOrd};
 use std::collections::{BTreeMap, BTreeSet};
 use std::convert::TryFrom;
@@ -19,6 +19,7 @@ pub mod utils;
 /// String implementation of Edn can be obtained with `.to_string()`
 #[derive(Debug, Hash, PartialEq, Eq, PartialOrd, Ord, Clone)]
 pub enum Edn {
+    Tagged(String, Box<Edn>),
     Vector(Vector),
     Set(Set),
     Map(Map),
@@ -323,6 +324,7 @@ impl core::fmt::Display for Edn {
             Edn::NamespacedMap(s, m) => format!(":{}{}", s, m),
             Edn::Nil => String::from("nil"),
             Edn::Empty => String::from(""),
+            Edn::Tagged(tag, edn) => format!("#{} {}", tag, edn),
         };
         write!(f, "{}", text)
     }
@@ -756,7 +758,7 @@ impl std::str::FromStr for Edn {
 
     /// Parses a `&str` that contains an Edn into `Result<Edn, EdnError>`
     fn from_str(s: &str) -> Result<Self, Self::Err> {
-        let clean = String::from(s.maybe_replace("#{", "@").trim_start());
+        let clean = String::from(s.trim_start());
         let mut tokens = parse::tokenize(&clean);
         let edn = parse::parse(tokens.next(), &mut tokens)?;
         Ok(edn)
