@@ -312,148 +312,6 @@ impl<A: Serialize, B: Serialize, C: Serialize, D: Serialize, E: Serialize, F: Se
     }
 }
 
-/// [DEPRECATED - use `edn-derive::Serialize`instead] `ser_struct!` creates a struct with the serialization trait already implemented:
-///
-/// `
-/// ser_struct! {
-///     #[derive(Debug)]
-///     struct Foo {
-///         foo: i32,
-///         bar: String,
-///         boz: char
-///     }
-/// }
-/// `
-///
-/// then you can use the struct normally:
-/// ```rust
-/// #[macro_use]
-/// extern crate edn_rs;
-/// use edn_rs::serialize::Serialize;
-///
-/// fn main() {
-///     ser_struct! {
-///         #[derive(Debug)]
-///         struct Foo {
-///             foo: i32,
-///             bar: String,
-///             boz: char
-///         }
-///     }
-///     let foo  = Foo { foo: 1, bar: String::from("blahb"), boz: 'c'};
-///
-///     assert_eq!(foo.serialize(), "{ :foo 1, :bar \"blahb\", :boz \\c, }");
-/// }
-/// ```
-///
-/// There is also the possibility to create a public struct. This is done by adding the `pub` keyword
-/// before the structs naming, `pub struct Foo {`. Note that all inner fields will be public as well.
-/// ```
-/// #![recursion_limit="512"]
-/// #[macro_use] extern crate edn_rs;
-///
-/// #[test]
-/// fn pub_struct() {
-///     let edn = helper::Edn {
-///         val: 6i32,
-///         tuples: (3i32, true, 'd')
-///     };
-///
-///     assert_eq!(edn.val, 6i32);
-///     assert_eq!(edn.tuples, (3i32, true, 'd'));
-/// }
-///
-/// mod helper {
-///     use std::collections::{HashMap, HashSet};
-///     use crate::edn_rs::serialize::Serialize;
-///
-///     ser_struct!{
-///         #[derive(Debug, Clone)]
-///         pub struct Edn {
-///             val: i32,
-///             tuples: (i32, bool, char),
-///         }
-///     }
-/// }
-/// ```
-///
-/// Note than when you `serialize` `_` will become `-`, `__` will become `.` and `___` will become `/`
-/// **PLEASE USE `#[derive(Debug)]` for now**
-#[macro_export]
-#[deprecated]
-macro_rules! ser_struct {
-    (@gen () -> {$(#[$attr:meta])* struct $name:ident $(($id:ident: $ty:ty))*}) => {
-        $(#[$attr])* struct $name { $($id: $ty),* }
-
-        impl Serialize for $name {
-            fn serialize(self) -> String {
-                let mut s = String::new();
-                let mut v = Vec::new();
-                println!("[ser_struct is DEPRECATED - use `edn-derive::Serialize`instead]");
-
-                $(
-                    v.push(format!("{}", stringify!($id)));
-                )*
-                let hm_field_names = $crate::serialize::field_names(v);
-                s.push_str("{ ");
-                $(
-                    s.push_str(&hm_field_names.get(&format!("{}", stringify!($id))).expect("fails to parse field name"));
-                    s.push_str(" ");
-                    s.push_str(&self.$id.serialize());
-                    s.push_str(", ");
-                )*
-                s.push_str("}");
-                s
-            }
-        }
-    };
-
-    (@gen () -> {$(#[$attr:meta])* pub struct $name:ident $(($id:ident: $ty:ty))*}) => {
-        $(#[$attr])* pub struct $name { $(pub $id: $ty),* }
-
-        impl Serialize for $name {
-            fn serialize(self) -> String {
-                let mut s = String::new();
-                let mut v = Vec::new();
-                println!("[ser_struct is DEPRECATED - use `edn-derive::Serialize`instead]");
-                $(
-                    v.push(format!("{}", stringify!($id)));
-                )*
-                let hm_field_names = $crate::serialize::field_names(v);
-                s.push_str("{ ");
-                $(
-                    s.push_str(&hm_field_names.get(&format!("{}", stringify!($id))).expect("fails to parse field name"));
-                    s.push_str(" ");
-                    s.push_str(&self.$id.serialize());
-                    s.push_str(", ");
-                )*
-                s.push_str("}");
-                s
-            }
-        }
-    };
-
-    // last field
-    (@gen ($id:tt: $ty:ty) -> {$($output:tt)*}) => {
-        ser_struct!(@gen () -> {$($output)* ($id: $ty)});
-    };
-
-    // next field
-    (@gen ($id:tt: $ty:ty, $($next:tt)*) -> {$($output:tt)*}) => {
-        ser_struct!(@gen ($($next)*) -> {$($output)* ($id: $ty)});
-    };
-
-    // entry point
-    ($(#[$attr:meta])* struct $name:ident { $($input:tt)*} ) => {
-        ser_struct!(@gen ($($input)*) -> {$(#[$attr])* struct $name});
-    };
-
-     // pub struct
-     ($(#[$attr:meta])* pub struct $name:ident { $($input:tt)*} ) => {
-        ser_struct!(@gen ($($input)*) -> {$(#[$attr])* pub struct $name});
-    };
-}
-
 #[cfg(test)]
 mod test {
     use super::*;
@@ -481,25 +339,6 @@ mod test {
         assert_eq!(true.serialize(), String::from("true"));
     }
 
-    #[test]
-    fn basic_struct_ser() {
-        ser_struct! {
-            #[derive(Debug)]
-            struct Foo {
-                foo: i32,
-                bar: String,
-                boz: char
-            }
-        }
-        let actual = Foo {
-            foo: 1,
-            bar: String::from("blahb"),
-            boz: 'c',
-        };
-
-        assert_eq!(actual.serialize(), "{ :foo 1, :bar \"blahb\", :boz \\c, }");
-    }
-
     #[test]
     fn tuples() {
         let t2 = (12i32, 3.5f32);
@@ -737,39 +576,6 @@ mod test {
         );
     }
 
-    #[test]
-    fn out_pub_struct_ser() {
-        ser_struct! {
-            #[derive(Debug)]
-            pub struct Foo {
-                foo: i32,
-                bar: String,
-                boz: char
-            }
-        }
-        let actual = Foo {
-            foo: 1,
-            bar: String::from("blahb"),
-            boz: 'c',
-        };
-
-        assert_eq!(actual.serialize(), "{ :foo 1, :bar \"blahb\", :boz \\c, }");
-    }
-
-    #[test]
-    fn struct_fields_special_chars() {
-        ser_struct! {
-            #[derive(Debug)]
-            #[allow(non_snake_case)]
-            pub struct Foo {
-                foo__bar___boz: i32,
-            }
-        }
-
-        let foobar = Foo { foo__bar___boz: 3 };
-        assert_eq!(foobar.serialize(), "{ :foo.bar/boz 3, }")
-    }
-
     #[test]
     fn multi_sized_tuples() {
         assert_eq!((1,).serialize(), "(1)");
